@@ -15,6 +15,10 @@ __all__ = [
     "ProjectIssueResourceMilestoneEvent",
     "ProjectIssueResourceMilestoneEventManager",
     "ProjectIssueResourceStateEvent",
+    "ProjectIssueResourceIterationEventManager",
+    "ProjectIssueResourceWeightEventManager",
+    "ProjectIssueResourceIterationEvent",
+    "ProjectIssueResourceWeightEvent",
     "ProjectIssueResourceStateEventManager",
     "ProjectMergeRequestResourceLabelEvent",
     "ProjectMergeRequestResourceLabelEventManager",
@@ -29,7 +33,7 @@ __all__ = [
 
 class Event(RESTObject):
     _id_attr = None
-    _short_print_attr = "target_title"
+    _repr_attr = "target_title"
 
 
 class EventManager(ListMixin, RESTManager):
@@ -116,6 +120,40 @@ class ProjectIssueResourceStateEventManager(RetrieveMixin, RESTManager):
         )
 
 
+class ProjectIssueResourceIterationEvent(RESTObject):
+    pass
+
+
+class ProjectIssueResourceIterationEventManager(RetrieveMixin, RESTManager):
+    _path = "/projects/{project_id}/issues/{issue_iid}/resource_iteration_events"
+    _obj_cls = ProjectIssueResourceIterationEvent
+    _from_parent_attrs = {"project_id": "project_id", "issue_iid": "iid"}
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectIssueResourceIterationEvent:
+        return cast(
+            ProjectIssueResourceIterationEvent, super().get(id=id, lazy=lazy, **kwargs)
+        )
+
+
+class ProjectIssueResourceWeightEvent(RESTObject):
+    pass
+
+
+class ProjectIssueResourceWeightEventManager(RetrieveMixin, RESTManager):
+    _path = "/projects/{project_id}/issues/{issue_iid}/resource_weight_events"
+    _obj_cls = ProjectIssueResourceWeightEvent
+    _from_parent_attrs = {"project_id": "project_id", "issue_iid": "iid"}
+
+    def get(
+        self, id: Union[str, int], lazy: bool = False, **kwargs: Any
+    ) -> ProjectIssueResourceWeightEvent:
+        return cast(
+            ProjectIssueResourceWeightEvent, super().get(id=id, lazy=lazy, **kwargs)
+        )
+
+
 class ProjectMergeRequestResourceLabelEvent(RESTObject):
     pass
 
